package esac.archive.ehst.common.constants.client;

/**
 * Utility class to specify HTTP constants (servlet param names, status codes, etc...) contents.
 *
 * @author Nicolas Fajersztejn
 */
public class EhstHttpConstants {

    /**
     * Default constructor, it should not be called.
     */
    protected EhstHttpConstants() {
        // prevents calls from subclass
        throw new UnsupportedOperationException();
    }

    // Target Resolver servlet params
    public static final String SERVLET_PARAM_TARGET_NAME = "TARGET_NAME";
    public static final String SERVLET_PARAM_RESOLVER_TYPE = "RESOLVER_TYPE";

    // JSON Attribute and Values for default Target Resolver responses
    public static final String JSON_ATTRIBUTE_RESOLVER_NUMBER_OF_RESULTS_RESOLVER = "1";

    public static final String JSON_ATTRIBUTE_RESOLVER_STATUS_CODE = "RESOLVER_STATUS_CODE";

    public static final String JSON_VALUE_RESOLVER_STATUS_CODE_OK = "200";

    public static final String JSON_ATTRIBUTE_MESSAGE = "MESSAGE";

    public static final String JSON_ATTRIBUTE_EXTRA_INFO = "EXTRA_INFO";

    public static final String JSON_ATTRIBUTE_INPUT_PREFIX = "INPUT_";

    public static final String JSON_ATTRIBUTE_RA_DEG = "RA_DEGREES";

    public static final String JSON_ATTRIBUTE_DEC_DEG_ = "DEC_DEGREES";

    public static final String JSON_ATTRIBUTE_RA_HOURS = "RA_HOURS";

    public static final String JSON_ATTRIBUTE_RA_SEXAGESIMAL = "RA_SEXAGESIMALS";

    public static final String JSON_ATTRIBUTE_DEC_SEXAGESIMAL = "DEC_SEXAGESIMAL";

    public static final String JSON_ATTRIBUTE_TIME_TAKEN = "Time taken";

    public static final String JSON_VALUE_TARGET_RESOLVED = "Target resolved";

    public static final String JSON_VALUE_TARGET_NOT_FOUND = "Target not found";

    // /////////////////////////////////////////////////////////////////////////
    // / TARGET HTTP status codes
    // /////////////////////////////////////////////////////////////////////////

    // Target Resolver Service Not Available
    public static final int STATUS_CODE_TARGET_RESOLVER_SERVICE_NOT_AVAILABLE = 998;

    // Target Not Found Status code
    public static final int STATUS_CODE_TARGET_NOT_FOUND = 999;

    // /////////////////////////////////////////////////////////////////////////
    // / Servlet parameters
    // /////////////////////////////////////////////////////////////////////////

    // Generic params
    public static final String SERVLET_PARAM_OBSERVATION_ID = "OBSERVATION_ID";

    /** Resource class param. */
    public static final String SERVLET_PARAM_RESOURCE_CLASS = "RESOURCE_CLASS";

    /** Adql QUERY param. */
    public static final String SERVLET_PARAM_ADQL_QUERY = "ADQLQUERY";

    /** Return type param. */
    public static final String SERVLET_PARAM_RETURN_TYPE = "RETURN_TYPE";

    /** Enum for all the values of Return type. */
    public enum ServletValueReturnType {
        JSON, VOTABLE, CSV, ASCII;
    }

    /** Fits servlets param. */
    public final static String FITS_SERVLET_PARAM_REQUEST_TYPE = "REQUEST_TYPE";
    public final static String FITS_SERVLET_PARAM_REQUEST_TYPE_GETAXIS = "getaxislist";
    public final static String FITS_SERVLET_PARAM_REQUEST_TYPE_GETHDUS = "gethdulist";
    public final static String FITS_SERVLET_PARAM_HDU_ID = "HDU_ID";
    public final static String FITS_SERVLET_PARAM_YAXIS = "YAXIS";

    // Text to write in results file when value is null
    public static final String DEFAULT_DISPLAY_STRING_FOR_NULL_VALUE = "-";

    // Text to write in results file when value is proprietary
    public static final String DEFAULT_DISPLAY_STRING_FOR_PROPRIETARY_VALUE = "Proprietary";

    // Text to write in results file when image/icon is proprietary
    public static final String PROPRIETARY_IMAGE_STRING = "PROPRIETARY_IMAGE";

}
